==> blancoCsv-1.1.3-src.zip: src/blanco/resourcebundle/valueobject/BlancoResourceBundleBundleStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.resourcebundle.valueobject;

import java.util.List;

/**
 * \[Xoh킷\̃NXBꖼpbP[WȂǊ{񂪊܂܂܂B
 */
public class BlancoResourceBundleBundleStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[Xoh̊ꖼB
     */
    private String fName;

    /**
     * tB[h [listLocale]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * ̃\[XohΉ郍P[̈ꗗB(Combinȅꍇɂ̂ݗL)
     */
    private List fListLocale = new java.util.ArrayList();

    /**
     * tB[h [package]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[WB
     */
    private String fPackage;

    /**
     * tB[h [suffix]
     *
     * ڂ̌^ [java.lang.String]<br>
     * NXɕt^TtBbNXB
     */
    private String fSuffix;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃\[Xohɑ΂B
     */
    private String fDescription;

    /**
     * tB[h [access]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["public"]<br>
     * ̃NX̃ANZXB{Iɂ public ŗp܂B
     */
    private String fAccess = "public";

    /**
     * tB[h [itemList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * eL[{l̏B
     */
    private List fItemList = new java.util.ArrayList();

    /**
     * tB[h [resourceItem]
     *
     * ڂ̌^ [blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure]<br>
     * [NɗptB[hB
     */
    private BlancoResourceBundleBundleItemStructure fResourceItem;

    /**
     * tB[h [currentLocale]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郍P[L܂B
     */
    private String fCurrentLocale;

    /**
     * tB[h [currentResourceString]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郊\[XL܂B
     */
    private String fCurrentResourceString;

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[Xoh̊ꖼB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[Xoh̊ꖼB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [listLocale]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * ̃\[XohΉ郍P[̈ꗗB(Combinȅꍇɂ̂ݗL)
     *
     * @param argListLocale tB[h[listLocale]Ɋi[l
     */
    public void setListLocale(final List argListLocale) {
        fListLocale = argListLocale;
    }

    /**
     * tB[h[listLocale]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * ̃\[XohΉ郍P[̈ꗗB(Combinȅꍇɂ̂ݗL)
     *
     * @return tB[h[listLocale]Ɋi[Ăl
     */
    public List getListLocale() {
        return fListLocale;
    }

    /**
     * tB[h [package]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[WB
     *
     * @param argPackage tB[h[package]Ɋi[l
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h[package]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[WB
     *
     * @return tB[h[package]Ɋi[Ăl
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [suffix]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NXɕt^TtBbNXB
     *
     * @param argSuffix tB[h[suffix]Ɋi[l
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h[suffix]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NXɕt^TtBbNXB
     *
     * @return tB[h[suffix]Ɋi[Ăl
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃\[Xohɑ΂B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃\[Xohɑ΂B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [access]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃NX̃ANZXB{Iɂ public ŗp܂B
     *
     * @param argAccess tB[h[access]Ɋi[l
     */
    public void setAccess(final String argAccess) {
        fAccess = argAccess;
    }

    /**
     * tB[h[access]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["public"]<br>
     * ̃NX̃ANZXB{Iɂ public ŗp܂B
     *
     * @return tB[h[access]Ɋi[Ăl
     */
    public String getAccess() {
        return fAccess;
    }

    /**
     * tB[h [itemList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * eL[{l̏B
     *
     * @param argItemList tB[h[itemList]Ɋi[l
     */
    public void setItemList(final List argItemList) {
        fItemList = argItemList;
    }

    /**
     * tB[h[itemList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * eL[{l̏B
     *
     * @return tB[h[itemList]Ɋi[Ăl
     */
    public List getItemList() {
        return fItemList;
    }

    /**
     * tB[h [resourceItem]̃Zb^[\bh
     *
     * ڂ̌^ [blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure]<br>
     * [NɗptB[hB
     *
     * @param argResourceItem tB[h[resourceItem]Ɋi[l
     */
    public void setResourceItem(final BlancoResourceBundleBundleItemStructure argResourceItem) {
        fResourceItem = argResourceItem;
    }

    /**
     * tB[h[resourceItem]̃Qb^[\bh
     *
     * ڂ̌^ [blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure]<br>
     * [NɗptB[hB
     *
     * @return tB[h[resourceItem]Ɋi[Ăl
     */
    public BlancoResourceBundleBundleItemStructure getResourceItem() {
        return fResourceItem;
    }

    /**
     * tB[h [currentLocale]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郍P[L܂B
     *
     * @param argCurrentLocale tB[h[currentLocale]Ɋi[l
     */
    public void setCurrentLocale(final String argCurrentLocale) {
        fCurrentLocale = argCurrentLocale;
    }

    /**
     * tB[h[currentLocale]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郍P[L܂B
     *
     * @return tB[h[currentLocale]Ɋi[Ăl
     */
    public String getCurrentLocale() {
        return fCurrentLocale;
    }

    /**
     * tB[h [currentResourceString]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郊\[XL܂B
     *
     * @param argCurrentResourceString tB[h[currentResourceString]Ɋi[l
     */
    public void setCurrentResourceString(final String argCurrentResourceString) {
        fCurrentResourceString = argCurrentResourceString;
    }

    /**
     * tB[h[currentResourceString]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郊\[XL܂B
     *
     * @return tB[h[currentResourceString]Ɋi[Ăl
     */
    public String getCurrentResourceString() {
        return fCurrentResourceString;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.resourcebundle.valueobject.BlancoResourceBundleBundleStructure[");
        buf.append("name=" + fName);
        buf.append(",listLocale=" + fListLocale);
        buf.append(",package=" + fPackage);
        buf.append(",suffix=" + fSuffix);
        buf.append(",description=" + fDescription);
        buf.append(",access=" + fAccess);
        buf.append(",itemList=" + fItemList);
        buf.append(",resourceItem=" + fResourceItem);
        buf.append(",currentLocale=" + fCurrentLocale);
        buf.append(",currentResourceString=" + fCurrentResourceString);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoCsv-1.2.1-src.zip: src/blanco/resourcebundle/valueobject/BlancoResourceBundleBundleStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.resourcebundle.valueobject;

import java.util.List;

/**
 * \[Xoh킷\̃NXBꖼpbP[WȂǊ{񂪊܂܂܂B
 */
public class BlancoResourceBundleBundleStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[Xoh̊ꖼB
     */
    private String fName;

    /**
     * tB[h [listLocale]
     *
     * ڂ̌^ [java.util.List<java.lang.String>]<br>
     * Kl   [new java.util.ArrayList<java.lang.String>()]<br>
     * ̃\[XohΉ郍P[̈ꗗB(Combinȅꍇɂ̂ݗL)
     */
    private List<java.lang.String> fListLocale = new java.util.ArrayList<java.lang.String>();

    /**
     * tB[h [package]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[WB
     */
    private String fPackage;

    /**
     * tB[h [suffix]
     *
     * ڂ̌^ [java.lang.String]<br>
     * NXɕt^TtBbNXB
     */
    private String fSuffix;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃\[Xohɑ΂B
     */
    private String fDescription;

    /**
     * tB[h [access]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["public"]<br>
     * ̃NX̃ANZXB{Iɂ public ŗp܂B
     */
    private String fAccess = "public";

    /**
     * tB[h [itemList]
     *
     * ڂ̌^ [java.util.List<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure>]<br>
     * Kl   [new java.util.ArrayList<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure>()]<br>
     * eL[{l̏B
     */
    private List<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure> fItemList = new java.util.ArrayList<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure>();

    /**
     * tB[h [resourceItem]
     *
     * ڂ̌^ [blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure]<br>
     * [NɗptB[hB
     */
    private BlancoResourceBundleBundleItemStructure fResourceItem;

    /**
     * tB[h [currentLocale]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郍P[L܂B
     */
    private String fCurrentLocale;

    /**
     * tB[h [currentResourceString]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郊\[XL܂B
     */
    private String fCurrentResourceString;

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[Xoh̊ꖼB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[Xoh̊ꖼB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [listLocale]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<java.lang.String>]<br>
     * ̃\[XohΉ郍P[̈ꗗB(Combinȅꍇɂ̂ݗL)
     *
     * @param argListLocale tB[h[listLocale]Ɋi[l
     */
    public void setListLocale(final List<java.lang.String> argListLocale) {
        fListLocale = argListLocale;
    }

    /**
     * tB[h[listLocale]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<java.lang.String>]<br>
     * Kl   [new java.util.ArrayList<java.lang.String>()]<br>
     * ̃\[XohΉ郍P[̈ꗗB(Combinȅꍇɂ̂ݗL)
     *
     * @return tB[h[listLocale]Ɋi[Ăl
     */
    public List<java.lang.String> getListLocale() {
        return fListLocale;
    }

    /**
     * tB[h [package]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[WB
     *
     * @param argPackage tB[h[package]Ɋi[l
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h[package]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[WB
     *
     * @return tB[h[package]Ɋi[Ăl
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [suffix]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NXɕt^TtBbNXB
     *
     * @param argSuffix tB[h[suffix]Ɋi[l
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h[suffix]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NXɕt^TtBbNXB
     *
     * @return tB[h[suffix]Ɋi[Ăl
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃\[Xohɑ΂B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃\[Xohɑ΂B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [access]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̃NX̃ANZXB{Iɂ public ŗp܂B
     *
     * @param argAccess tB[h[access]Ɋi[l
     */
    public void setAccess(final String argAccess) {
        fAccess = argAccess;
    }

    /**
     * tB[h[access]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["public"]<br>
     * ̃NX̃ANZXB{Iɂ public ŗp܂B
     *
     * @return tB[h[access]Ɋi[Ăl
     */
    public String getAccess() {
        return fAccess;
    }

    /**
     * tB[h [itemList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure>]<br>
     * eL[{l̏B
     *
     * @param argItemList tB[h[itemList]Ɋi[l
     */
    public void setItemList(final List<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure> argItemList) {
        fItemList = argItemList;
    }

    /**
     * tB[h[itemList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure>]<br>
     * Kl   [new java.util.ArrayList<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure>()]<br>
     * eL[{l̏B
     *
     * @return tB[h[itemList]Ɋi[Ăl
     */
    public List<blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure> getItemList() {
        return fItemList;
    }

    /**
     * tB[h [resourceItem]̃Zb^[\bh
     *
     * ڂ̌^ [blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure]<br>
     * [NɗptB[hB
     *
     * @param argResourceItem tB[h[resourceItem]Ɋi[l
     */
    public void setResourceItem(final BlancoResourceBundleBundleItemStructure argResourceItem) {
        fResourceItem = argResourceItem;
    }

    /**
     * tB[h[resourceItem]̃Qb^[\bh
     *
     * ڂ̌^ [blanco.resourcebundle.valueobject.BlancoResourceBundleBundleItemStructure]<br>
     * [NɗptB[hB
     *
     * @return tB[h[resourceItem]Ɋi[Ăl
     */
    public BlancoResourceBundleBundleItemStructure getResourceItem() {
        return fResourceItem;
    }

    /**
     * tB[h [currentLocale]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郍P[L܂B
     *
     * @param argCurrentLocale tB[h[currentLocale]Ɋi[l
     */
    public void setCurrentLocale(final String argCurrentLocale) {
        fCurrentLocale = argCurrentLocale;
    }

    /**
     * tB[h[currentLocale]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郍P[L܂B
     *
     * @return tB[h[currentLocale]Ɋi[Ăl
     */
    public String getCurrentLocale() {
        return fCurrentLocale;
    }

    /**
     * tB[h [currentResourceString]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郊\[XL܂B
     *
     * @param argCurrentResourceString tB[h[currentResourceString]Ɋi[l
     */
    public void setCurrentResourceString(final String argCurrentResourceString) {
        fCurrentResourceString = argCurrentResourceString;
    }

    /**
     * tB[h[currentResourceString]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ݏĂ郊\[XL܂B
     *
     * @return tB[h[currentResourceString]Ɋi[Ăl
     */
    public String getCurrentResourceString() {
        return fCurrentResourceString;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.resourcebundle.valueobject.BlancoResourceBundleBundleStructure[");
        buf.append("name=" + fName);
        buf.append(",listLocale=" + fListLocale);
        buf.append(",package=" + fPackage);
        buf.append(",suffix=" + fSuffix);
        buf.append(",description=" + fDescription);
        buf.append(",access=" + fAccess);
        buf.append(",itemList=" + fItemList);
        buf.append(",resourceItem=" + fResourceItem);
        buf.append(",currentLocale=" + fCurrentLocale);
        buf.append(",currentResourceString=" + fCurrentResourceString);
        buf.append("]");
        return buf.toString();
    }
}
